#
# spec file for package lua-ldbus
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define flavor lua53
%define mod_name ldbus
Version:        0.0+git20190816.9e176fe
Release:        4.5
Summary:        Lua bindings to dbus
License:        MIT
Group:          Development/Libraries/Other
URL:            https://github.com/daurnimator/ldbus/
Source:         lua-ldbus-%{version}.tar.xz
Patch0:         lua54.patch
BuildRequires:  %{flavor}-devel
BuildRequires:  lua-macros
Requires:       %{flavor}
%if 0%{?suse_version} < 1330
BuildRequires:  dbus-1-devel
%else
BuildRequires:  pkgconfig(dbus-1)
%endif
%lua_provides
%if "%{flavor}" == ""
Name:           lua-%{mod_name}
ExclusiveArch:  do_not_build
%else
Name:           %{flavor}-%{mod_name}
%endif

%description
ldbus is a C binding to dbus for Lua.

%prep
%autosetup -n lua-ldbus-%{version} -p1

%if "%{flavor}" != "lua53"
sed -i -e "s/lua5.3/lua%{lua_version}/" src/Makefile
%endif

%build
%if 0%{?suse_version} < 1330
export CFLAGS="-I/usr/include/lua%{lua_version} -I/usr/include/dbus-1.0 -I/usr/lib64/dbus-1.0/include"
%if "%{flavor}" != "lua53"
export CFLAGS="$CFLAGS -Ivendor/compat-5.3"
%endif
%endif
cd src
make %{?_make_output_sync} %{?_smp_mflags}

%install
cd src
%make_install LUA_LIBDIR='$(DESTDIR)%{lua_archdir}'

%files
%license LICENSE
%{lua_archdir}/ldbus.so

%changelog
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Blank line required after %%%%autosetup on SLE12
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Fix missing dependency on lua-macros (boo#1205612)
* Wed Jan 25 2023 Michal Suchanek <msuchanek@suse.de>
- Opencode %%make_build to prevent build failure when not defined.
* Thu Feb 18 2021 Callum Farmer <gmbr3@opensuse.org>
- Use %%lua_provides macro for default lua versioning
* Thu Jul  9 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Added lua54.patch to fix building with Lua 5.4
* Mon Jul  6 2020 Matej Cepl <mcepl@suse.com>
- Add lua54 as new build target
* Thu Oct 24 2019 alarrosa@suse.com
- Update to version 0.0+git20190816.9e176fe:
  * Squashed 'vendor/compat-5.3/' changes from bc91f40..daebe77
  * src/Makefile: Use LDFLAGS
  * src/Makefile: Introduce LUA_PKGNAME
  * src/ldbus.h: Remove now unused ldbus_callback_udata
  * src/: Move 'timeout' callbacks to new callback management style
  * src/: Move 'watch' callbacks to new callback management style
  * Use ldbus_callback_indexes enum instead of hard-coding
  * src/connection.c: Use different style of callback management for wakeup and dispatch functions
  * src/connection.c: Use different style of callback management for VTable functions
  * src/pending_call.c: Use different style of callback management
  * Squashed 'vendor/compat-5.3/' changes from 924cdb2..bc91f40
* Wed Oct 31 2018 mcepl@suse.com
- Make package building even on SLE-12/Leap 42
* Mon Oct 30 2017 jmatejek@suse.com
- do not build for Lua 5.2
* Fri Aug 18 2017 opensuse-packaging@opensuse.org
- Update to version 0.0+git20161023.e277e22:
  * rockspec: Add library to external_dependencies
  * .gitignore: add .rock files
  * Add binding to dbus_bus_get_private
  * Mention get_private in README
  * src/: Fix segfault when callback registered from a thread which gets collected
  * README: Fix formatting in table
  * rockspec: Formatting
  * rockspec: Only claim compat up to 5.3
  * rockspec: Add libdir for dbus
  * Allow overriding the pkg-config executable
* Fri Aug 18 2017 alarrosa@suse.com
- Initial release
